<img src="../../Certego.png" alt="Certego" width="200" />

# 🐍 Python linters


## 🔧 Dependencies
To use locally, install these dependencies:
```bash
pip install -r requirements-linters.txt
```

To add additional dependecies to CI, insert them in your personal `requirements-linters.txt` file (inside *<requirements_path>* folder).


## 📖 How to use
Customize files inside configurations.

**Note:** actually there is no way to extend configurations with other files.


## 💻 How to configure your IDE
W.I.P.
